import{_ as p}from"./BjGx28ax.js";import{_ as s,a}from"./Dq8znpD1.js";import{h as i,v as _,o as c,w as t,b as o}from"./dgvVcRbD.js";import"./BrAY5X9P.js";import"./DLwfb9rl.js";import"./8lporG8B.js";import"./PjxHOgst.js";import"./PBSS8bwl.js";import"./DjY5_9nl.js";import"./BesS-_33.js";import"./k_JGKJJP.js";import"./D8ey85JT.js";import"./ClvrI8Td.js";import"./DlAUqK2U.js";import"./C1qmphIB.js";import"./Dc4I8EvL.js";import"./BngqlKF6.js";import"./BWdbJVRO.js";import"./BULhecZF.js";import"./BnobUxhI.js";const A=i({__name:"test-md",setup(d){const m={id:1,message_type:"user",content:String.raw`
Test message with **markdown**!
 `};return(f,u)=>{const r=p,e=s,n=a;return c(),_(n,null,{default:t(()=>[o(e,null,{default:t(()=>[o(r,{message:m})]),_:1})]),_:1})}}});export{A as default};
