import{_ as s}from"./Dq9G4vIx.js";import{h as i,e as c,u as p,B as u,k as a,v as m,o as _,g as l}from"./dgvVcRbD.js";import"./CVKV6eJo.js";import"./DX3tX3Y8.js";import"./BoDFvG8T.js";import"./BtWIKuWo.js";import"./Bw0uuBPj.js";import"./XTzszJDu.js";const q=i({__name:"sign-in",setup(d){const{t:e}=c();p({title:e("pageTitle.signIn")});const r=u(),o=a(()=>{const t=r.query.redirect;return typeof t=="string"&&t.length>0?t:void 0});return(t,g)=>{const n=s;return _(),m(n,{scene:"sign-in","redirect-url":l(o)},null,8,["redirect-url"])}}});export{q as default};
